"""Auto-generated file, do not edit by hand. SE metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SE = PhoneMetadata(id='SE', country_code=46, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='\\d{9}', possible_length=(9,)),
    fixed_line=PhoneNumberDesc(example_number='123456789'))
