"""Per-prefix data, mapping each prefix to a dict of locale:name.

Auto-generated file, do not edit by hand.
"""
from phonenumbers.util import u

# Copyright (C) 2011-2021 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

data = {
 '1650212':{'en': 'US carrier'},
 '1650213':{'en': 'US carrier2'},
 '244262':{'en': 'Angolan fixed line carrier'},
 '244917':{'en': 'Angolan carrier'},
 '4411':{'en': 'British fixed line carrier'},
 '4473':{'en': 'British carrier', 'sv': u('Brittisk operat\u00f6r')},
 '44760':{'en': 'British pager'},
}
