"""Auto-generated file, do not edit by hand. BR metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_BR = PhoneMetadata(id='BR', country_code=55, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='\\d{8,10}', possible_length=(10,), possible_length_local_only=(8,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='\\d{8,10}', example_number='12345678', possible_length=(10,), possible_length_local_only=(8,)))
